=====
sqlew
=====
.. image:: https://travis-ci.org/tomokinakamaru/sqlew.svg?branch=master
    :target: https://travis-ci.org/tomokinakamaru/sqlew
    :alt: sqlew Build

PEP 249 compat DB client wrapper & query formatting.
